[llvm-commits] CVS: llvm/lib/Target/X86/X86InstrBuilder.h

Chris Lattner lattner at cs.uiuc.edu
Sun Jan 12 18:50:01 PST 2003


Changes in directory llvm/lib/Target/X86:

X86InstrBuilder.h updated: 1.4 -> 1.5

---
Log message:

Add support for frame and constant pool references


---
Diffs of the changes:

Index: llvm/lib/Target/X86/X86InstrBuilder.h
diff -u llvm/lib/Target/X86/X86InstrBuilder.h:1.4 llvm/lib/Target/X86/X86InstrBuilder.h:1.5
--- llvm/lib/Target/X86/X86InstrBuilder.h:1.4	Sat Dec 28 14:26:58 2002
+++ llvm/lib/Target/X86/X86InstrBuilder.h	Sun Jan 12 18:45:53 2003
@@ -42,12 +42,24 @@
 
 /// addFrameReference - This function is used to add a reference to the base of
 /// an abstract object on the stack frame of the current function.  This
 /// reference has base register <noreg> and a FrameIndex offset until it is
 /// resolved.
 ///
 inline const MachineInstrBuilder &
-addFrameReference(const MachineInstrBuilder &MIB, int FI) {
-  return MIB.addReg(0).addZImm(1).addMReg(0).addFrameIndex(FI);
+addFrameReference(const MachineInstrBuilder &MIB, int FI, int Offset = 0) {
+  return MIB.addFrameIndex(FI).addZImm(1).addMReg(0).addSImm(Offset);
+}
+
+/// addConstantPoolReference - This function is used to add a reference to the
+/// base of a constant value spilled to the per-function constant pool.  The
+/// reference has base register ConstantPoolIndex offset which is retained until
+/// either machine code emission or assembly output.  This allows an optional
+/// offset to be added as well.
+///
+inline const MachineInstrBuilder &
+addConstantPoolReference(const MachineInstrBuilder &MIB, unsigned CPI,
+			 int Offset = 0) {
+  return MIB.addConstantPoolIndex(CPI).addZImm(1).addMReg(0).addSImm(Offset);
 }
 
 #endif
@@ -42,12 +42,24 @@
 /// addFrameReference - This function is used to add a reference to the base of
 /// an abstract object on the stack frame of the current function.  This
-/// reference has base register <noreg> and a FrameIndex offset until it is
-/// resolved.
+/// reference has base register as the FrameIndex offset until it is resolved.
+/// This allows a constant offset to be specified as well...
 ///
 inline const MachineInstrBuilder &





More information about the llvm-commits mailing list